texinfo-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[7692] change --virtual-index to --index-search plus --all


From: gavinsmith0123
Subject: [7692] change --virtual-index to --index-search plus --all
Date: Sun, 19 Mar 2017 16:04:00 -0400 (EDT)

Revision: 7692
          http://svn.sv.gnu.org/viewvc/?view=rev&root=texinfo&revision=7692
Author:   gavin
Date:     2017-03-19 16:04:00 -0400 (Sun, 19 Mar 2017)
Log Message:
-----------
change --virtual-index to --index-search plus --all

Modified Paths:
--------------
    trunk/ChangeLog
    trunk/info/info.c

Modified: trunk/ChangeLog
===================================================================
--- trunk/ChangeLog     2017-03-19 19:00:01 UTC (rev 7691)
+++ trunk/ChangeLog     2017-03-19 20:04:00 UTC (rev 7692)
@@ -1,5 +1,12 @@
 2017-03-19  Gavin Smith  <address@hidden>
 
+       * info/info.c (virtual_index_p): Remove variable.
+       (long_options): Remove "--virtual-index".
+       (main): Don't check for --virtual-index option.  Use the
+       combination of --index-search and --all for this functionality.
+
+2017-03-19  Gavin Smith  <address@hidden>
+
        * tp/Texinfo/ModulePath.pm.in ($VERSION): Define variable.
 
 2017-03-19  Gavin Smith  <address@hidden>

Modified: trunk/info/info.c
===================================================================
--- trunk/info/info.c   2017-03-19 19:00:01 UTC (rev 7691)
+++ trunk/info/info.c   2017-03-19 20:04:00 UTC (rev 7692)
@@ -42,10 +42,6 @@
    apropos, this puts the user at the node, running info. */
 static int index_search_p = 0;
 
-/* Searching all indices for INDEX_SEARCH_STRING, and display a list of
-   the results. */
-static int virtual_index_p = 0;
-
 /* Non-zero means look for the node which describes the invocation
    and command-line options of the program, and start the info
    session at that node.  */
@@ -148,7 +144,6 @@
   { "variable", 1, 0, 'v' },
   { "version", 0, &print_version_p, 1 },
   { "vi-keys", 0, &vi_keys_p, 1 },
-  { "virtual-index", 1, 0, VIRTIDX_OPTION },
   { "where", 0, &print_where_p, 1 },
 #if defined(__MSDOS__) || defined(__MINGW32__)
   { "speech-friendly", 0, &speech_friendly, 1 },
@@ -799,9 +794,6 @@
           break;
 
           /* User has specified a string to search all indices for. */
-        case VIRTIDX_OPTION:
-          virtual_index_p = 1;
-          /* fall through */
         case IDXSRCH_OPTION:
           index_search_p = 1;
           free (index_search_string);
@@ -930,7 +922,7 @@
   add_pointer_to_array (0, ref_index, ref_list, ref_slots, 2);
   ref_index--;
 
-  if (all_matches_p)
+  if (all_matches_p && !index_search_p)
     {
       /* --all */
       if (!user_filename && argv[0])
@@ -977,9 +969,9 @@
 
       get_initial_file (&argc, &argv, &error);
 
       /* If the user specified `--virtual-index=STRING', create
          and display the menu of results. */
-      if (virtual_index_p && initial_file)
+      if (index_search_p && all_matches_p && initial_file)
         {
           FILE_BUFFER *initial_fb;
           initial_fb = info_find_file (initial_file);
@@ -977,9 +969,9 @@
       get_initial_file (&argc, &argv, &error);
 
-      /* If the user specified `--virtual-index=STRING', create
+      /* If the user specified `--index-search=STRING --all', create
          and display the menu of results. */




reply via email to

[Prev in Thread] Current Thread [Next in Thread]